@@ -35,6 +35,7 @@
 #include "rc-wtmp.h"
 #include "version.h"
 
+static const char *path_default = "/sbin:/usr/sbin:/bin:/usr/bin";
 static const char *rc_default_runlevel = "default";
 
 static pid_t do_openrc(const char *runlevel)
@@ -53,7 +54,7 @@ static pid_t do_openrc(const char *runlevel)
 			sigemptyset(&signals);
 			sigprocmask(SIG_SETMASK, &signals, NULL);
 			printf("Starting %s runlevel\n", runlevel);
-			execl("/sbin/openrc", "/sbin/openrc", runlevel, NULL);
+			execlp("openrc", "openrc", runlevel, NULL);
 			perror("exec");
 			break;
 		default:
@@ -88,7 +89,7 @@ static void init(const char *default_runlevel)
 
 static void handle_reexec(char *my_name)
 {
-	execl(my_name, my_name, "reexec", NULL);
+	execlp(my_name, my_name, "reexec", NULL);
 	return;
 }
 
@@ -183,6 +184,9 @@ int main(int argc, char **argv)
 	sigaction(SIGINT, &sa, NULL);
 	reboot(RB_DISABLE_CAD);
 
+	/* set default path */
+	setenv("PATH", path_default, 1);
+
 	if (! reexec)
 		init(default_runlevel);
 
